@@ -3,10 +3,10 @@ import numpy as np
 import scipy
 from scipy.sparse import csr_matrix
 from gpuinfo import GPUInfo as g
-import gpuadder
+#import gpuadder - that was our cuda package
 import time
 
-from pynvml import *
+#from pynvml import * - hopefully we can comment that out, I have no idea, what that is
 
 import os
 os.environ['PYOPENCL_COMPILER_OUTPUT'] = '0'
